@@ -18,10 +18,12 @@ __all__ = [
 ]
 
 __title__ = "flake8-import-order"
-__summary__ = "Flake8 plugin that checks the ordering of import statements."
+__summary__ = (
+    "Flake8 and pylama plugin that checks the ordering of import statements."
+)
 __uri__ = "https://github.com/public/flake8-import-order"
 
-__version__ = "0.1"
+__version__ = "0.2"
 
 __author__ = "Alex Stapleton"
 __email__ = "alexs@prol.etari.at"
